==> jc-1.4.0.tar.gz: java__5fcup/lalr__5fstate__24StateItem.h <==
// class java_cup.lalr_state$StateItem

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ed0c8d12cedd976 java__5fcup_lalr__5fstate__24StateItem

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_lalr__5fstate__24StateItem_H_
#define _JC_java__5fcup_lalr__5fstate__24StateItem_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java__5fcup_lalr__5fitem$object;
struct _jc_java__5fcup_lalr__5fstate$object;

// Typedefs
typedef struct _jc_java__5fcup_lalr__5fstate__24StateItem$sub_refs	_jc_java__5fcup_lalr__5fstate__24StateItem$sub_refs;
typedef struct _jc_java__5fcup_lalr__5fstate__24StateItem$sub_nonrefs	_jc_java__5fcup_lalr__5fstate__24StateItem$sub_nonrefs;
typedef struct _jc_java__5fcup_lalr__5fstate__24StateItem$refs	_jc_java__5fcup_lalr__5fstate__24StateItem$refs;
typedef struct _jc_java__5fcup_lalr__5fstate__24StateItem$nonrefs	_jc_java__5fcup_lalr__5fstate__24StateItem$nonrefs;
typedef struct _jc_java__5fcup_lalr__5fstate__24StateItem$object	_jc_java__5fcup_lalr__5fstate__24StateItem$object;

typedef const struct _jc_java__5fcup_lalr__5fstate__24StateItem$vmethods	_jc_java__5fcup_lalr__5fstate__24StateItem$vmethods;
typedef const struct _jc_java__5fcup_lalr__5fstate__24StateItem$vtable	_jc_java__5fcup_lalr__5fstate__24StateItem$vtable;
typedef const struct _jc_java__5fcup_lalr__5fstate__24StateItem$vtype	_jc_java__5fcup_lalr__5fstate__24StateItem$vtype;

// Constructors
extern void _jc_java__5fcup_lalr__5fstate__24StateItem$method$_init$425973a5622ae960(_jc_env *, struct _jc_java__5fcup_lalr__5fstate__24StateItem$object *, struct _jc_java__5fcup_lalr__5fstate$object *, struct _jc_java__5fcup_lalr__5fstate$object *, struct _jc_java__5fcup_lalr__5fitem$object *);

// Virtual methods
extern jboolean _jc_java__5fcup_lalr__5fstate__24StateItem$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java__5fcup_lalr__5fstate__24StateItem$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java__5fcup_lalr__5fstate__24StateItem$method$hashCode$53152098849316df(_jc_env *, struct _jc_java__5fcup_lalr__5fstate__24StateItem$object *);

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_lalr__5fstate__24StateItem$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java__5fcup_lalr__5fstate__24StateItem$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java__5fcup_lalr__5fstate__24StateItem$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java__5fcup_lalr__5fstate__24StateItem$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java__5fcup_lalr__5fstate__24StateItem$object *);
};

// Vtable
struct _jc_java__5fcup_lalr__5fstate__24StateItem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_lalr__5fstate__24StateItem$vmethods	java__5fcup_lalr__5fstate__24StateItem;
};

// Vtype
struct _jc_java__5fcup_lalr__5fstate__24StateItem$vtype {
	_jc_type			type;
	_jc_java__5fcup_lalr__5fstate__24StateItem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_lalr__5fstate__24StateItem$sub_refs {
	struct _jc_java__5fcup_lalr__5fstate$object	*state;
	struct _jc_java__5fcup_lalr__5fitem$object	*item;
	struct _jc_java__5fcup_lalr__5fstate$object	*this__240;
};

// Reference instance fields (object)
struct _jc_java__5fcup_lalr__5fstate__24StateItem$refs {
    _jc_java__5fcup_lalr__5fstate__24StateItem$sub_refs	java__5fcup_lalr__5fstate__24StateItem;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_lalr__5fstate__24StateItem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_lalr__5fstate__24StateItem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_lalr__5fstate__24StateItem$sub_nonrefs	java__5fcup_lalr__5fstate__24StateItem;
};

// Object instance structure
struct _jc_java__5fcup_lalr__5fstate__24StateItem$object {
	_jc_java__5fcup_lalr__5fstate__24StateItem$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_lalr__5fstate__24StateItem$vtype	*vtype;
	_jc_java__5fcup_lalr__5fstate__24StateItem$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_lalr__5fstate__24StateItem$vtype _jc_java__5fcup_lalr__5fstate__24StateItem$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_lalr__5fstate__24StateItem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_lalr__5fstate__24StateItem$class_object;

#endif	/* _JC_java__5fcup_lalr__5fstate__24StateItem_H_ */

==> jc-1.4.6.tar.gz: java__5fcup/lalr__5fstate__24StateItem.h <==
// class java_cup.lalr_state$StateItem

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ed0c8d12cedd976 java__5fcup_lalr__5fstate__24StateItem

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_lalr__5fstate__24StateItem_H_
#define _JC_java__5fcup_lalr__5fstate__24StateItem_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java__5fcup_lalr__5fitem$object;
struct _jc_java__5fcup_lalr__5fstate$object;

// Typedefs
typedef struct _jc_java__5fcup_lalr__5fstate__24StateItem$sub_refs	_jc_java__5fcup_lalr__5fstate__24StateItem$sub_refs;
typedef struct _jc_java__5fcup_lalr__5fstate__24StateItem$sub_nonrefs	_jc_java__5fcup_lalr__5fstate__24StateItem$sub_nonrefs;
typedef struct _jc_java__5fcup_lalr__5fstate__24StateItem$refs	_jc_java__5fcup_lalr__5fstate__24StateItem$refs;
typedef struct _jc_java__5fcup_lalr__5fstate__24StateItem$nonrefs	_jc_java__5fcup_lalr__5fstate__24StateItem$nonrefs;
typedef struct _jc_java__5fcup_lalr__5fstate__24StateItem$object	_jc_java__5fcup_lalr__5fstate__24StateItem$object;

typedef const struct _jc_java__5fcup_lalr__5fstate__24StateItem$vmethods	_jc_java__5fcup_lalr__5fstate__24StateItem$vmethods;
typedef const struct _jc_java__5fcup_lalr__5fstate__24StateItem$vtable	_jc_java__5fcup_lalr__5fstate__24StateItem$vtable;
typedef const struct _jc_java__5fcup_lalr__5fstate__24StateItem$vtype	_jc_java__5fcup_lalr__5fstate__24StateItem$vtype;

// Constructors
extern void _jc_java__5fcup_lalr__5fstate__24StateItem$method$_init$425973a5622ae960(_jc_env *, struct _jc_java__5fcup_lalr__5fstate__24StateItem$object *, struct _jc_java__5fcup_lalr__5fstate$object *, struct _jc_java__5fcup_lalr__5fstate$object *, struct _jc_java__5fcup_lalr__5fitem$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java__5fcup_lalr__5fstate__24StateItem$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java__5fcup_lalr__5fstate__24StateItem$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java__5fcup_lalr__5fstate__24StateItem$method$hashCode$53152098849316df(_jc_env *, struct _jc_java__5fcup_lalr__5fstate__24StateItem$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_lalr__5fstate__24StateItem$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java__5fcup_lalr__5fstate__24StateItem$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java__5fcup_lalr__5fstate__24StateItem$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java__5fcup_lalr__5fstate__24StateItem$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java__5fcup_lalr__5fstate__24StateItem$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java__5fcup_lalr__5fstate__24StateItem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_lalr__5fstate__24StateItem$vmethods	java__5fcup_lalr__5fstate__24StateItem;
};

// Vtype
struct _jc_java__5fcup_lalr__5fstate__24StateItem$vtype {
	_jc_type			type;
	_jc_java__5fcup_lalr__5fstate__24StateItem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_lalr__5fstate__24StateItem$sub_refs {
	struct _jc_java__5fcup_lalr__5fstate$object	*state;
	struct _jc_java__5fcup_lalr__5fitem$object	*item;
	struct _jc_java__5fcup_lalr__5fstate$object	*this__240;
};

// Reference instance fields (object)
struct _jc_java__5fcup_lalr__5fstate__24StateItem$refs {
    _jc_java__5fcup_lalr__5fstate__24StateItem$sub_refs	java__5fcup_lalr__5fstate__24StateItem;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_lalr__5fstate__24StateItem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_lalr__5fstate__24StateItem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_lalr__5fstate__24StateItem$sub_nonrefs	java__5fcup_lalr__5fstate__24StateItem;
};

// Object instance structure
struct _jc_java__5fcup_lalr__5fstate__24StateItem$object {
	_jc_java__5fcup_lalr__5fstate__24StateItem$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_lalr__5fstate__24StateItem$vtype	*vtype;
	_jc_java__5fcup_lalr__5fstate__24StateItem$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_lalr__5fstate__24StateItem$vtype _jc_java__5fcup_lalr__5fstate__24StateItem$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_lalr__5fstate__24StateItem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_lalr__5fstate__24StateItem$class_object;

#endif	/* _JC_java__5fcup_lalr__5fstate__24StateItem_H_ */
